==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/cs.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Daný název je příliš dlouhý",
    "The given web address is too long" : "Daná webová adresa je příliš dlouhá",
    "The given web address is not a valid URL" : "Daná webová adresa není platné URL",
    "The given legal notice address is too long" : "Daná adresa právního upozornění je příliš dlouhá",
    "The given legal notice address is not a valid URL" : "Daná adresa právního upozornění není platné URL",
    "The given privacy policy address is too long" : "Daná adresa prohlášení o zásadách ochrany osobních údajů je příliš dlouhá",
    "The given privacy policy address is not a valid URL" : "Daná adresa prohlášení o zásadách ochrany soukromí není platné URL",
    "The given slogan is too long" : "Daný slogan je příliš dlouhý",
    "The given color is invalid" : "Daná barva není platná",
    "Disable-user-theming should be true or false" : "Volba „Zabránit uživatelům měnit vzhled“ by měla mít hodnotu ano nebo ne",
    "Saved" : "Uloženo",
    "Invalid app given" : "Zadána neplatná aplikace",
    "Invalid type for setting \"defaultApp\" given" : "Zadán neplatný typ nastavení pro „defaultApp",
    "Invalid setting key" : "Neplatný klíč nastavení",
    "The file was uploaded" : "Soubor byl nahrán",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Velikost nahrávaného souboru překračuje limit nastavený direktivou upload_max_filesize v php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Velikost nahrávaného souboru překračuje limit, nastavený direktivou MAX_FILE_SIZE, zadanou v HTML formuláři",
    "The file was only partially uploaded" : "Soubor byl nahrán pouze z části",
    "No file was uploaded" : "Nebyl nahrán žádný soubor",
    "Missing a temporary folder" : "Chybí složka pro dočasné soubory",
    "Could not write file to disk" : "Soubor se nedaří zapsat na datové úložiště",
    "A PHP extension stopped the file upload" : "PHP rozšíření zastavilo nahrávání souboru",
    "No file uploaded" : "Nenahrán žádný soubor",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Už používáte svůj vlastní motiv vzhledu. Nastavení aplikace pro změnu motivu vzhledu tím mohou být přepsána.",
    "Theming" : "Motiv vzhledu",
    "Appearance and accessibility" : "Vzhled a zpřístupnění",
    "PHP Imagick module" : "PHP modul Imagick",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Ačkoli je zapnutá aplikace pro opatřování motivem vzhledu, není zapnutý PHP modul „imagick“. Aby vytváření ikon webů správně fungovalo, je zapotřebí tento modul nainstalovat a zapnout.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "PHP modul „imagick“ na této instanci nemá podporu pro SVG. Aby byla zajištěna lepší kompatibilita, doporučuje se ji nainstalovat.",
    "Dark theme with high contrast mode" : "Tmavý motiv vzhledu s režimem vysokého kontrastu",
    "Enable dark high contrast mode" : "Používat tmavý režim s vysokým kontrastem",
    "Similar to the high contrast mode, but with dark colours." : "Podobné režimu s vysokým kontrastem, ale s tmavými barvami.",
    "Dark theme" : "Tmavý motiv vzhledu",
    "Enable dark theme" : "Používat tmavý motiv vzhledu",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Tmavý motiv vzhledu pro ulevení vašim očím pomocí omezení celkové svítivosti a jasu.",
    "System default theme" : "Výchozí systémový vzhled",
    "Enable the system default" : "Použít systémový výchozí",
    "Using the default system appearance." : "Používá se výchozí systémový vzhled.",
    "Dyslexia font" : "Písmo pro dyslektiky",
    "Enable dyslexia font" : "Používat písmo pro dyslektiky",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic je bezplatné písmo (font) navržené tak, aby odpomáhalo od některých běžných chybování při čtení, způsobených dyslexií.",
    "High contrast mode" : "Režim s vysokým kontrastem",
    "Enable high contrast mode" : "Zapnout režim s vysokým kontrastem",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Režim s vysokým kontrastem pro usnadnění orientace při pohybu po aplikaci. Vizuální kvalita bude snížena, zato zřetelnost se zlepší.",
    "Light theme" : "Světlý motiv vzhledu",
    "Enable the default light theme" : "Používat výchozí světlý vzhled",
    "The default light appearance." : "Výchozí světlý vzhled.",
    "Legal notice" : "Právní upozornění",
    "Privacy policy" : "Zásady ochrany soukromí",
    "Adjust the Nextcloud theme" : "Upravit motiv vzhledu Nextcloud",
    "Name" : "Název",
    "Web link" : "Webový odkaz",
    "a safe home for all your data" : "bezpečný domov pro všechna vaše data",
    "Slogan" : "Slogan",
    "Primary color" : "Primární barva",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Hlavní barva slouží pro zvýraznění prvků jako jsou důležitá tlačítka. Může být mírně přizpůsobena podle stávajícího schématu barev.",
    "Legal notice link" : "Odkaz na právní upozornění",
    "Privacy policy link" : "Odkaz na zásady ochrany osobních údajů",
    "Header logo" : "Logo v záhlaví",
    "Upload new header logo" : "Nahrát nové logo záhlaví",
    "Favicon" : "Ikona webu",
    "Upload new favicon" : "Nahrát novou ikonu webu",
    "User settings" : "Nastavení pro uživatele",
    "Disable user theming" : "Zabránit uživatelům měnit vzhled",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Ačkoli je možné vybrat a přizpůsobit si svou instanci, uživatelé si mohou změnit pozadí a barvy. Pokud chcete vámi nastavené přizpůsobení vynutit, můžete toto zapnout.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Motivy umožňují jednoduše přizpůsobit vzhled a dojem z vaší instance a podporovaných klientů. Projeví se všem uživatelům.",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Namísto obrázku je na pozadí také možné nastavit jednolitou barvu. Pokud použijete obrázek na pozadí, změna této barvy ovlivní barvu ikon nabídky aplikací.",
    "Background color" : "Barva pozadí",
    "Upload new logo" : "Nahrát nové logo",
    "Logo" : "Logo",
    "Upload new background and login image" : "Nahrát nový obrázek na pozadí a přihlašovací obrazovku",
    "Background and login image" : "Obrázek na pozadí a přihlašovací obrazovce",
    "Advanced options" : "Pokročilé předvolby",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Nainstalujte rozšíření ImageMagick PHP s podporou SVG obrázků, které automaticky vytváří favicon na základě nahraného loga a barvy.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Přístupnost pro všechny je pro nás velmi důležitá. Splňujeme webové standardy a zajišťujeme, aby všechno bylo použitelné i bez myši a s asistenčním softwarem, jako například čtečkami obrazovky. Máme za cíl být v souladu s doporučeními {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 na úrovni AA, při použití motivu vzhledu s vysokým kontrastem dokonce na úrovni AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Pokud naleznete jakékoli problémy, neváhejte s jejich nahlášením do {issuetracker}našeho systému pro správu hlášení{linkend}. A pokud se chcete zapojit, přidejte se k {designteam}týmu našich designérů{linkend}!",
    "Unable to apply the setting." : "Nastavení nebylo možné uplatnit.",
    "Appearance and accessibility settings" : "Nastavení vzhledu a zpřístupnění",
    "Misc accessibility options" : "Ostatní předvolby pro přístupnost",
    "Enable blur background filter (may increase GPU load)" : "Zapnout filtr rozmazávající pozadí (může zvýšit vytížení výpočetní jednotky pro grafiku)",
    "Customization has been disabled by your administrator" : "Přizpůsobení si bylo vypnuto správcem",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Nastavte hlavní barvu pro zvýraznění důležitých prvků. Barva slouží pro prvky jako například hlavní tlačítka a může se trochu lišit, protože je přizpůsobována aby plnila požadavky na zpřístupnění pro postižené.",
    "Background and color" : "Pozadí a barva",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Jako pozadí je možné nastavit obrázek z výchozí sady, uživatelsky určený nahraný obrázek, nebo jednolitá barva.",
    "Keyboard shortcuts" : "Klávesové zkratky",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "V některých případech mohou klávesové zkratky kolidovat s těmi v rámci nástrojů pro zpřístupnění. Aby tyto nástroje fungovaly správně, je možné zde vypnout veškeré klávesové zkratky pro Nextcloud. Toto také vypne veškeré klávesové zkratky v Nextcloud aplikacích.",
    "Disable all keyboard shortcuts" : "Vypnout veškeré klávesové zkratky",
    "Current selected app: {app}, position {position} of {total}" : "Nyní vybraná aplikace: {app}, pozice {position} z {total}",
    "Move up" : "Přesunout výše",
    "Move down" : "Přesunout dolů",
    "Select a background from your files" : "Vyberte obrázek na pozadí ze svých souborů",
    "Select background" : "Vybrat pozadí",
    "No background has been selected" : "Nevybráno žádné pozadí",
    "Custom background" : "Uživatelsky určený obrázek na pozadí",
    "Plain background" : "Jednolité pozadí",
    "Default background" : "Výchozí obrázek na pozadí",
    "Theme selection is enforced" : "Výběr motivu vzhledu je vynucen",
    "Could not set the app order" : "Nepodařilo se nastavit pořadí aplikací",
    "Could not reset the app order" : "Nepodařilo se vrátit pořadí aplikací na výchozí",
    "Navigation bar settings" : "Nastavení pruhu navigace",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Pořadí v liště navigace je možné nastavit. První položkou bude výchozí aplikace, otevíranou po přihlášení se nebo při kliknutí na logo.",
    "The default app can not be changed because it was configured by the administrator." : "Výchozí aplikace nebude změněna protože byla nastavená správcem.",
    "The app order was changed, to see it in action you have to reload the page." : "Pořadí aplikací bylo změněno – aby se projevilo, je třeba stránku načíst znovu.",
    "Reset default app order" : "Vrátit pořadí aplikací na výchozí",
    "Could not set primary color" : "Nepodařilo se nastavit primární barvu",
    "Reset primary color" : "Vrátit nastavení primární barvy na výchozí hodnotu",
    "Could not set global default apps" : "Nepodařilo se nastavit globálně výchozí aplikace",
    "Default app" : "Výchozí aplikace",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Výchozí aplikace je ta, která je např. otevřena po přihlášení nebo po kliknutí na logo v nabídce.",
    "Use custom default app" : "Použít uživatelsky určenou výchozí aplikaci",
    "Global default app" : "Globálně výchozí aplikace",
    "Global default apps" : "Globálně výchozí aplikace",
    "Default app priority" : "Priorita výchozí aplikace",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Pokud aplikace není pro daného uživatele povolena, bude použita další aplikace v pořadí priority.",
    "Select a custom color" : "Vybrat uživatelsky určenou barvu",
    "Reset to default" : "Vrátit zpět na výchozí hodnoty",
    "Upload" : "Nahrát",
    "Remove background image" : "Odebrat obrázek z pozadí",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Přístupnost pro všechny je pro nás velmi důležitá. Splňujeme webové standardy a zajišťujeme, aby všechno bylo použitelné i bez myši a s asistenčním software, jako například čtečkami obrazovky. Máme za cíl být v souladu s doporučeními {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 na úrovni AA, při použití motivu vzhledu s vysokým kontrastem dokonce na úrovni AAA.",
    ". Unable to apply the setting." : ". Nastavení nebylo možné uplatnit."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/cs.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Daný název je příliš dlouhý",
    "The given web address is too long" : "Daná webová adresa je příliš dlouhá",
    "The given web address is not a valid URL" : "Daná webová adresa není platné URL",
    "The given legal notice address is too long" : "Daná adresa právního upozornění je příliš dlouhá",
    "The given legal notice address is not a valid URL" : "Daná adresa právního upozornění není platné URL",
    "The given privacy policy address is too long" : "Daná adresa prohlášení o zásadách ochrany osobních údajů je příliš dlouhá",
    "The given privacy policy address is not a valid URL" : "Daná adresa prohlášení o zásadách ochrany soukromí není platné URL",
    "The given slogan is too long" : "Daný slogan je příliš dlouhý",
    "The given color is invalid" : "Daná barva není platná",
    "%1$s should be true or false" : "%1$s by mělo mít hodnotu true (platí) nebo false (neplatí)",
    "%1$s can only be set to %2$s through the API" : "%1$s je možné na %2$s nastavit pouze prostřednictvím API",
    "Invalid setting key" : "Neplatný klíč nastavení",
    "Saved" : "Uloženo",
    "Invalid app given" : "Zadána neplatná aplikace",
    "Invalid type for setting \"defaultApp\" given" : "Zadán neplatný typ nastavení pro „defaultApp",
    "The file was uploaded" : "Soubor byl nahrán",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Velikost nahrávaného souboru překračuje limit nastavený direktivou upload_max_filesize v php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Velikost nahrávaného souboru překračuje limit, nastavený direktivou MAX_FILE_SIZE, zadanou v HTML formuláři",
    "The file was only partially uploaded" : "Soubor byl nahrán pouze z části",
    "No file was uploaded" : "Nebyl nahrán žádný soubor",
    "Missing a temporary folder" : "Chybí složka pro dočasné soubory",
    "Could not write file to disk" : "Soubor se nedaří zapsat na datové úložiště",
    "A PHP extension stopped the file upload" : "PHP rozšíření zastavilo nahrávání souboru",
    "No file uploaded" : "Nenahrán žádný soubor",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Už používáte svůj vlastní motiv vzhledu. Nastavení aplikace pro změnu motivu vzhledu tím mohou být přepsána.",
    "Theming" : "Motiv vzhledu",
    "Appearance and accessibility" : "Vzhled a zpřístupnění",
    "PHP Imagick module" : "PHP modul Imagick",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Ačkoli je zapnutá aplikace pro opatřování motivem vzhledu, není zapnutý PHP modul „imagick“. Aby vytváření ikon webů správně fungovalo, je zapotřebí tento modul nainstalovat a zapnout.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "PHP modul „imagick“ na této instanci nemá podporu pro SVG. Aby byla zajištěna lepší kompatibilita, doporučuje se ji nainstalovat.",
    "Dark theme with high contrast mode" : "Tmavý motiv vzhledu s režimem vysokého kontrastu",
    "Enable dark high contrast mode" : "Používat tmavý režim s vysokým kontrastem",
    "Similar to the high contrast mode, but with dark colours." : "Podobné režimu s vysokým kontrastem, ale s tmavými barvami.",
    "Dark theme" : "Tmavý motiv vzhledu",
    "Enable dark theme" : "Používat tmavý motiv vzhledu",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Tmavý motiv vzhledu pro ulevení vašim očím pomocí omezení celkové svítivosti a jasu.",
    "System default theme" : "Výchozí systémový vzhled",
    "Enable the system default" : "Použít systémový výchozí",
    "Using the default system appearance." : "Používá se výchozí systémový vzhled.",
    "Dyslexia font" : "Písmo pro dyslektiky",
    "Enable dyslexia font" : "Používat písmo pro dyslektiky",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic je bezplatné písmo (font) navržené tak, aby odpomáhalo od některých běžných chybování při čtení, způsobených dyslexií.",
    "High contrast mode" : "Režim s vysokým kontrastem",
    "Enable high contrast mode" : "Zapnout režim s vysokým kontrastem",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Režim s vysokým kontrastem pro usnadnění orientace při pohybu po aplikaci. Vizuální kvalita bude snížena, zato zřetelnost se zlepší.",
    "Light theme" : "Světlý motiv vzhledu",
    "Enable the default light theme" : "Používat výchozí světlý vzhled",
    "The default light appearance." : "Výchozí světlý vzhled.",
    "Legal notice" : "Právní upozornění",
    "Privacy policy" : "Zásady ochrany soukromí",
    "Adjust the Nextcloud theme" : "Upravit motiv vzhledu Nextcloud",
    "Could not set global default apps" : "Nepodařilo se nastavit globálně výchozí aplikace",
    "Navigation bar settings" : "Nastavení pruhu navigace",
    "Default app" : "Výchozí aplikace",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Výchozí aplikace je ta, která je např. otevřena po přihlášení nebo po kliknutí na logo v nabídce.",
    "Use custom default app" : "Použít uživatelsky určenou výchozí aplikaci",
    "Global default app" : "Globálně výchozí aplikace",
    "Global default apps" : "Globálně výchozí aplikace",
    "Default app priority" : "Priorita výchozí aplikace",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Pokud aplikace není pro daného uživatele povolena, bude použita další aplikace v pořadí priority.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Motivy umožňují jednoduše přizpůsobit vzhled a dojem z vaší instance a podporovaných klientů. Projeví se všem uživatelům.",
    "Name" : "Název",
    "Web link" : "Webový odkaz",
    "Slogan" : "Slogan",
    "a safe home for all your data" : "bezpečný domov pro všechna vaše data",
    "Legal notice link" : "Odkaz na právní upozornění",
    "Privacy policy link" : "Odkaz na zásady ochrany osobních údajů",
    "Background and color" : "Pozadí a barva",
    "Primary color" : "Primární barva",
    "Set the default primary color, used to highlight important elements." : "Nastavit výchozí primární barvu, sloužící pro zvýrazňování důležitých prvků.",
    "The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Barva slouží pro prvky jako například hlavní tlačítka a může se trochu lišit, protože je přizpůsobována aby plnila požadavky na zpřístupnění pro postižené.",
    "Background color" : "Barva pozadí",
    "When no background image is set the background color will be used." : "Pokud není nastavený žádný obrázek na pozadí, bude použita barva pozadí.",
    "Otherwise the background color is by default generated from the background image, but can be adjusted to fine tune the color of the navigation icons." : "V opačném případě je barva pozadí ve výchozím stavu vytvořena z obrázku na pozadí, ale je možné ji uzpůsobit pro doladění barvy ikon navigace.",
    "Use a plain background color instead of a background image." : "Použít pro pozadí jednolitou barvu namísto obrázku.",
    "Remove background image" : "Odebrat obrázek z pozadí",
    "Background image" : "Obrázek na pozadí",
    "Favicon" : "Ikona webu",
    "Logo" : "Logo",
    "Navigation bar logo" : "Logo pruhu navigace",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Ačkoli je možné vybrat a přizpůsobit si svou instanci, uživatelé si mohou změnit pozadí a barvy. Pokud chcete vámi nastavené přizpůsobení vynutit, můžete toto zapnout.",
    "Disable user theming" : "Zabránit uživatelům měnit vzhled",
    "Current selected app: {app}, position {position} of {total}" : "Nyní vybraná aplikace: {app}, pozice {position} z {total}",
    "Navigation bar app order" : "Pořadí aplikací v liště navigace",
    "Move up" : "Přesunout výše",
    "Move down" : "Přesunout dolů",
    "Theme selection is enforced" : "Výběr motivu vzhledu je vynucen",
    "Could not set the app order" : "Nepodařilo se nastavit pořadí aplikací",
    "Could not reset the app order" : "Nepodařilo se vrátit pořadí aplikací na výchozí",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Pořadí v liště navigace je možné nastavit. První položkou bude výchozí aplikace, otevíranou po přihlášení se nebo při kliknutí na logo.",
    "The default app can not be changed because it was configured by the administrator." : "Výchozí aplikace nebude změněna protože byla nastavená správcem.",
    "The app order was changed, to see it in action you have to reload the page." : "Pořadí aplikací bylo změněno – aby se projevilo, je třeba stránku načíst znovu.",
    "Reset default app order" : "Vrátit pořadí aplikací na výchozí",
    "Select a background from your files" : "Vyberte obrázek na pozadí ze svých souborů",
    "Select background" : "Vybrat pozadí",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Jako pozadí je možné nastavit obrázek z výchozí sady, uživatelsky určený nahraný obrázek, nebo jednolitá barva.",
    "Custom background" : "Uživatelsky určený obrázek na pozadí",
    "Plain background" : "Jednolité pozadí",
    "Default background" : "Výchozí obrázek na pozadí",
    "Default shipped background images" : "Výchozí dodávané obrázky na pozadí",
    "Keyboard shortcuts" : "Klávesové zkratky",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "V některých případech mohou klávesové zkratky kolidovat s těmi v rámci nástrojů pro zpřístupnění. Aby tyto nástroje fungovaly správně, je možné zde vypnout veškeré klávesové zkratky pro Nextcloud. Toto také vypne veškeré klávesové zkratky v Nextcloud aplikacích.",
    "Disable all keyboard shortcuts" : "Vypnout veškeré klávesové zkratky",
    "Could not set primary color" : "Nepodařilo se nastavit primární barvu",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Nastavte hlavní barvu pro zvýraznění důležitých prvků. Barva slouží pro prvky jako například hlavní tlačítka a může se trochu lišit, protože je přizpůsobována aby plnila požadavky na zpřístupnění pro postižené.",
    "Reset primary color" : "Vrátit nastavení primární barvy na výchozí hodnotu",
    "Reset to default" : "Vrátit zpět na výchozí hodnoty",
    "Non image file selected" : "Nevybrán žádný soubor s obrázekem",
    "Preview of the selected image" : "Náhled vybraného obrázku",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Přístupnost pro všechny je pro nás velmi důležitá. Splňujeme webové standardy a zajišťujeme, aby všechno bylo použitelné i bez myši a s asistenčním softwarem, jako například čtečkami obrazovky. Máme za cíl být v souladu s doporučeními {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 na úrovni AA, při použití motivu vzhledu s vysokým kontrastem dokonce na úrovni AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Pokud naleznete jakékoli problémy, neváhejte s jejich nahlášením do {issuetracker}našeho systému pro správu hlášení{linkend}. A pokud se chcete zapojit, přidejte se k {designteam}týmu našich designérů{linkend}!",
    "Unable to apply the setting." : "Nastavení nebylo možné uplatnit.",
    "Appearance and accessibility settings" : "Nastavení vzhledu a zpřístupnění",
    "Misc accessibility options" : "Ostatní předvolby pro přístupnost",
    "Enable blur background filter (may increase GPU load)" : "Zapnout filtr rozmazávající pozadí (může zvýšit vytížení výpočetní jednotky pro grafiku)",
    "Customization has been disabled by your administrator" : "Přizpůsobení si bylo vypnuto správcem",
    "Disable-user-theming should be true or false" : "Volba „Zabránit uživatelům měnit vzhled“ by měla mít hodnotu ano nebo ne",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Hlavní barva slouží pro zvýraznění prvků jako jsou důležitá tlačítka. Může být mírně přizpůsobena podle stávajícího schématu barev.",
    "Header logo" : "Logo v záhlaví",
    "Upload new header logo" : "Nahrát nové logo záhlaví",
    "Upload new favicon" : "Nahrát novou ikonu webu",
    "User settings" : "Nastavení pro uživatele",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Namísto obrázku je na pozadí také možné nastavit jednolitou barvu. Pokud použijete obrázek na pozadí, změna této barvy ovlivní barvu ikon nabídky aplikací.",
    "Upload new logo" : "Nahrát nové logo",
    "Upload new background and login image" : "Nahrát nový obrázek na pozadí a přihlašovací obrazovku",
    "Background and login image" : "Obrázek na pozadí a přihlašovací obrazovce",
    "Advanced options" : "Pokročilé předvolby",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Nainstalujte rozšíření ImageMagick PHP s podporou SVG obrázků, které automaticky vytváří favicon na základě nahraného loga a barvy.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Přístupnost pro všechny je pro nás velmi důležitá. Splňujeme webové standardy a zajišťujeme, aby všechno bylo použitelné i bez myši a s asistenčním software, jako například čtečkami obrazovky. Máme za cíl být v souladu s doporučeními {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 na úrovni AA, při použití motivu vzhledu s vysokým kontrastem dokonce na úrovni AAA.",
    ". Unable to apply the setting." : ". Nastavení nebylo možné uplatnit.",
    "No background has been selected" : "Nevybráno žádné pozadí",
    "Select a custom color" : "Vybrat uživatelsky určenou barvu",
    "Upload" : "Nahrát"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
